<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>MPRISFactory</name>
    <message>
        <location filename="../mprisfactory.cpp" line="31"/>
        <source>MPRIS Plugin</source>
        <translation>Greffon MPRIS</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="51"/>
        <source>About MPRIS Plugin</source>
        <translation>À propos du greffon MPRIS</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="52"/>
        <source>Qmmp MPRIS Plugin</source>
        <translation>Greffon MPRIS pour Qmmp</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
